@@ -1,3 +1,3 @@
 from .scorer import Scorer
 from .constants import Constants, Errors
-from .config import DefaultConfig
+from .config import Config
